# @Time : 2021/4/11 0:30 
# @Author : GanJianWen
# @File : __init__.py.py 
# @Email: 1727949032@qq.com
# @Software: PyCharm

from py3db.elasticsearch.elastic_search import ElasticSearch as ElasticSearch
